@@ -31,14 +31,11 @@
 #include "nautilus-window.h"
 #include "nautilus-window-slot.h"
 #include "nautilus-window-pane.h"
-#include "nautilus-spatial-window.h"
-#include "nautilus-navigation-window.h"
+#include "nautilus-navigation-state.h"
 #include "nautilus-bookmark-list.h"
 
 #include <libnautilus-private/nautilus-directory.h>
 
-struct _NautilusNavigationWindowPane;
-
 /* FIXME bugzilla.gnome.org 42575: Migrate more fields into here. */
 struct NautilusWindowDetails
 {
@@ -89,24 +86,15 @@ struct NautilusWindowDetails
 	gboolean initiated_unmount;
 
         NautilusApplication *application;
-};
 
-struct _NautilusNavigationWindowDetails {
         GtkWidget *content_paned;
         GtkWidget *content_box;
-        GtkActionGroup *navigation_action_group; /* owned by ui_manager */
-
-        GtkSizeGroup *header_size_group;
+        NautilusNavigationState *nav_state;
         
         /* Side Pane */
         int side_pane_width;
         GtkWidget *sidebar;
         gchar *sidebar_id;
-
-	/* Menus */
-        GtkActionGroup *go_menu_action_group;
-	guint refresh_go_menu_idle_id;
-        guint go_menu_merge_id;
         
         /* Toolbar */
         GtkWidget *toolbar;
@@ -114,59 +102,31 @@ struct _NautilusNavigationWindowDetails {
         guint extensions_toolbar_merge_id;
         GtkActionGroup *extensions_toolbar_action_group;
 
-        /* spinner */
-        gboolean    spinner_active;
-        GtkWidget  *spinner;
-
         /* focus widget before the location bar has been shown temporarily */
         GtkWidget *last_focus_widget;
         	
         /* split view */
         GtkWidget *split_view_hpane;
+
+        gboolean disable_chrome;
+
+        guint sidebar_width_handler_id;
 };
 
-#define NAUTILUS_MENU_PATH_BACK_ITEM			"/menu/Go/Back"
-#define NAUTILUS_MENU_PATH_FORWARD_ITEM			"/menu/Go/Forward"
-#define NAUTILUS_MENU_PATH_UP_ITEM			"/menu/Go/Up"
-
-#define NAUTILUS_MENU_PATH_RELOAD_ITEM			"/menu/View/Reload"
-#define NAUTILUS_MENU_PATH_ZOOM_IN_ITEM			"/menu/View/Zoom Items Placeholder/Zoom In"
-#define NAUTILUS_MENU_PATH_ZOOM_OUT_ITEM		"/menu/View/Zoom Items Placeholder/Zoom Out"
-#define NAUTILUS_MENU_PATH_ZOOM_NORMAL_ITEM		"/menu/View/Zoom Items Placeholder/Zoom Normal"
-
-#define NAUTILUS_COMMAND_BACK				"/commands/Back"
-#define NAUTILUS_COMMAND_FORWARD			"/commands/Forward"
-#define NAUTILUS_COMMAND_UP				"/commands/Up"
-
-#define NAUTILUS_COMMAND_RELOAD				"/commands/Reload"
-#define NAUTILUS_COMMAND_BURN_CD			"/commands/Burn CD"
-#define NAUTILUS_COMMAND_STOP				"/commands/Stop"
-#define NAUTILUS_COMMAND_ZOOM_IN			"/commands/Zoom In"
-#define NAUTILUS_COMMAND_ZOOM_OUT			"/commands/Zoom Out"
-#define NAUTILUS_COMMAND_ZOOM_NORMAL			"/commands/Zoom Normal"
-
 /* window geometry */
 /* Min values are very small, and a Nautilus window at this tiny size is *almost*
  * completely unusable. However, if all the extra bits (sidebar, location bar, etc)
  * are turned off, you can see an icon or two at this size. See bug 5946.
  */
 
-#define NAUTILUS_SPATIAL_WINDOW_MIN_WIDTH			100
-#define NAUTILUS_SPATIAL_WINDOW_MIN_HEIGHT			100
-#define NAUTILUS_SPATIAL_WINDOW_DEFAULT_WIDTH			500
-#define NAUTILUS_SPATIAL_WINDOW_DEFAULT_HEIGHT			300
-
-#define NAUTILUS_NAVIGATION_WINDOW_MIN_WIDTH			200
-#define NAUTILUS_NAVIGATION_WINDOW_MIN_HEIGHT			200
-#define NAUTILUS_NAVIGATION_WINDOW_DEFAULT_WIDTH		800
-#define NAUTILUS_NAVIGATION_WINDOW_DEFAULT_HEIGHT		550
+#define NAUTILUS_WINDOW_MIN_WIDTH		200
+#define NAUTILUS_WINDOW_MIN_HEIGHT		200
+#define NAUTILUS_WINDOW_DEFAULT_WIDTH		800
+#define NAUTILUS_WINDOW_DEFAULT_HEIGHT		550
 
 typedef void (*NautilusBookmarkFailedCallback) (NautilusWindow *window,
                                                 NautilusBookmark *bookmark);
 
-void               nautilus_window_set_status                            (NautilusWindow    *window,
-									  NautilusWindowSlot *slot,
-                                                                          const char        *status);
 void               nautilus_window_load_view_as_menus                    (NautilusWindow    *window);
 void               nautilus_window_load_extension_menus                  (NautilusWindow    *window);
 void               nautilus_window_initialize_menus                      (NautilusWindow    *window);
@@ -181,12 +141,6 @@ void               nautilus_menus_append_bookmark_to_menu                (Nautil
                                                                           guint              merge_id,
                                                                           GCallback          refresh_callback,
                                                                           NautilusBookmarkFailedCallback failed_callback);
-void               nautilus_window_update_find_menu_item                 (NautilusWindow    *window);
-void               nautilus_window_zoom_in                               (NautilusWindow    *window);
-void               nautilus_window_zoom_out                              (NautilusWindow    *window);
-void               nautilus_window_zoom_to_level                         (NautilusWindow    *window,
-                                                                          NautilusZoomLevel  level);
-void               nautilus_window_zoom_to_default                       (NautilusWindow    *window);
 
 NautilusWindowSlot *nautilus_window_open_slot                            (NautilusWindowPane *pane,
 									  NautilusWindowOpenSlotFlags flags);
@@ -195,7 +149,6 @@ void                nautilus_window_close_slot                           (Nautil
 NautilusWindowSlot *nautilus_window_get_slot_for_view                    (NautilusWindow *window,
 									  NautilusView   *view);
 
-GList *              nautilus_window_get_slots                           (NautilusWindow    *window);
 NautilusWindowSlot * nautilus_window_get_active_slot                     (NautilusWindow    *window);
 NautilusWindowSlot * nautilus_window_get_extra_slot                      (NautilusWindow    *window);
 void                 nautilus_window_set_active_slot                     (NautilusWindow    *window,
@@ -204,11 +157,6 @@ void                 nautilus_window_set_active_pane                     (Nautil
                                                                           NautilusWindowPane *new_pane);
 NautilusWindowPane * nautilus_window_get_active_pane                     (NautilusWindow *window);
 
-void               nautilus_send_history_list_changed                    (void);
-gboolean           nautilus_add_bookmark_to_history_list                 (NautilusBookmark  *bookmark);
-GList *            nautilus_get_history_list                             (void);
-void               nautilus_window_bookmarks_preference_changed_callback (gpointer           user_data);
-
 
 /* sync window GUI with current slot. Used when changing slots,
  * and when updating the slot state.
@@ -220,26 +168,17 @@ void nautilus_window_sync_title            (NautilusWindow *window,
 					    NautilusWindowSlot *slot);
 void nautilus_window_sync_zoom_widgets     (NautilusWindow *window);
 
-/* Navigation window menus */
-void               nautilus_navigation_window_initialize_actions                    (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_initialize_menus                      (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_remove_bookmarks_menu_callback        (NautilusNavigationWindow    *window);
+/* window menus */
+GtkActionGroup *nautilus_window_create_toolbar_action_group (NautilusWindow *window);
+void               nautilus_window_initialize_actions                    (NautilusWindow    *window);
+void               nautilus_window_initialize_menus                      (NautilusWindow    *window);
+void               nautilus_window_remove_bookmarks_menu_callback        (NautilusWindow    *window);
 
-void               nautilus_navigation_window_remove_bookmarks_menu_items           (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_update_show_hide_menu_items           (NautilusNavigationWindow     *window);
-void               nautilus_navigation_window_update_spatial_menu_item              (NautilusNavigationWindow     *window);
-void               nautilus_navigation_window_remove_go_menu_callback    (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_remove_go_menu_items       (NautilusNavigationWindow    *window);
+void               nautilus_window_remove_bookmarks_menu_items           (NautilusWindow    *window);
+void               nautilus_window_update_show_hide_menu_items           (NautilusWindow     *window);
 
-/* Navigation window toolbar */
-void               nautilus_navigation_window_activate_spinner                     (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_initialize_toolbars                   (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_load_extension_toolbar_items          (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_set_spinner_active                   (NautilusNavigationWindow    *window, 
-                                                                                     gboolean                     active);
-void               nautilus_navigation_window_go_back                               (NautilusNavigationWindow    *window);
-void               nautilus_navigation_window_go_forward                            (NautilusNavigationWindow    *window);
-void               nautilus_window_close_pane                                       (NautilusWindowPane *pane);
-void               nautilus_navigation_window_update_split_view_actions_sensitivity (NautilusNavigationWindow    *window);
+/* window toolbar */
+void               nautilus_window_close_pane                            (NautilusWindowPane *pane);
+void               nautilus_window_update_split_view_actions_sensitivity (NautilusWindow    *window);
 
 #endif /* NAUTILUS_WINDOW_PRIVATE_H */
